Learn R Programming

DataQualityDashboard (version 2.8.6)

.evaluateThresholds: Internal function to evaluate the data quality checks against given thresholds.

Description

Internal function to evaluate the data quality checks against given thresholds.

Usage

.evaluateThresholds(checkResults, tableChecks, fieldChecks, conceptChecks)

Value

A dataframe with updated check results including pass/fail status and threshold values

Arguments

checkResults

A dataframe containing the results of the data quality checks

tableChecks

A dataframe containing the table checks

fieldChecks

A dataframe containing the field checks

conceptChecks

A dataframe containing the concept checks