Internal function to put the results of each quality check into a dataframe.
.recordResult(
result = NULL,
check,
checkDescription,
sql,
executionTime = NA,
warning = NA,
error = NA
)A dataframe containing the check results
The result of the data quality check
The data quality check
The description of the data quality check
The fully qualified sql for the data quality check
The total time it took to execute the data quality check
Any warnings returned from the server
Any errors returned from the server