Internal function to run and process each data quality check.
.runCheck(
checkDescription,
tableChecks,
fieldChecks,
conceptChecks,
connectionDetails,
connection,
cdmDatabaseSchema,
vocabDatabaseSchema,
resultsDatabaseSchema,
writeTableName,
cohortDatabaseSchema,
cohortTableName,
cohortDefinitionId,
outputFolder,
sqlOnlyUnionCount,
sqlOnlyIncrementalInsert,
sqlOnly
)A dataframe containing the check results or SQL queries (NULL if sqlOnlyIncrementalInsert is TRUE)
The description of the data quality check
A dataframe containing the table checks
A dataframe containing the field checks
A dataframe containing the concept checks
A connectionDetails object for connecting to the CDM database
A connection for connecting to the CDM database using the DatabaseConnector::connect(connectionDetails) function.
The fully qualified database name of the CDM schema
The fully qualified database name of the vocabulary schema (default is to set it as the cdmDatabaseSchema)
The fully qualified database name of the results schema
The table tor write DQD results to. Used when sqlOnly or writeToTable is True.
The schema where the cohort table is located.
The name of the cohort table.
The cohort definition id for the cohort you wish to run the DQD on. The package assumes a standard OHDSI cohort table called 'Cohort'
The folder to output logs and SQL files to
(OPTIONAL) How many SQL commands to union before inserting them into output table (speeds processing when queries done in parallel). Default is 1.
(OPTIONAL) Boolean to determine whether insert check results and associated metadata into output table. Default is FALSE (for backwards compatability to <= v2.2.0)
Should the SQLs be executed (FALSE) or just returned (TRUE)?