Learn R Programming

DataQualityDashboard (version 2.8.6)

.summarizeResults: Internal function to summarize the results of the DQD run.

Description

Internal function to summarize the results of the DQD run.

Usage

.summarizeResults(checkResults)

Value

A list containing summary statistics of the check results

Arguments

checkResults

A dataframe containing the results of the checks after running against the database