Internal function to write the check results to a csv file.
.writeResultsToCsv(
checkResults,
csvPath,
columns = c("checkId", "failed", "passed", "isError", "notApplicable", "checkName",
"checkDescription", "thresholdValue", "notesValue", "checkLevel", "category",
"subcategory", "context", "checkLevel", "cdmTableName", "cdmFieldName", "conceptId",
"unitConceptId", "numViolatedRows", "pctViolatedRows", "numDenominatorRows",
"executionTime", "notApplicableReason", "error", "queryText"),
delimiter = ","
)NULL (writes results to CSV file)
A dataframe containing the fully summarized data quality check results
The path where the csv file should be written
The columns to be included in the csv file. Default is all columns in the checkResults dataframe.
The delimiter for the file. Default is comma.