Internal function to evaluate the data quality checks against given thresholds.
.evaluateThresholds(checkResults, tableChecks, fieldChecks, conceptChecks)A dataframe with updated check results including pass/fail status and threshold values
A dataframe containing the results of the data quality checks
A dataframe containing the table checks
A dataframe containing the field checks
A dataframe containing the concept checks