.hasNAchecks: Determines if all checks are present expected to calculate the 'Not Applicable' status
Description
Determines if all checks are present expected to calculate the 'Not Applicable' status
Usage
.hasNAchecks(checkResults)
Value
A logical value indicating whether all required checks are present
Arguments
- checkResults
A dataframe containing the results of the data quality checks