Internal function to write the check results to a table in the database. Requires write access to the database
.writeResultsToTable(
connectionDetails,
resultsDatabaseSchema,
checkResults,
writeTableName,
cohortDefinitionId
)NULL (writes results to database table)
A connectionDetails object for connecting to the CDM database
The fully qualified database name of the results schema
A dataframe containing the fully summarized data quality check results
The name of the table to be written to the database. Default is "dqdashboard_results".
(OPTIONAL) The cohort definition id for the cohort you wish to run the DQD on. The package assumes a standard OHDSI cohort table called 'Cohort' with the fields cohort_definition_id and subject_id.